ccip_offramp

package
v0.0.0-...-c15b584 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: MIT Imports: 7 Imported by: 5

Documentation

Index

Constants

This section is empty.

Variables

Functions

func Compile

func Compile(ccipAddress, mcmsAddress aptos.AccountAddress, registerMCMSEntrypoints bool) (compile.CompiledPackage, error)

Types

type CCIPOfframp

type CCIPOfframp interface {
	Address() aptos.AccountAddress

	Offramp() module_offramp.OfframpInterface
}

func Bind

func Bind(address aptos.AccountAddress, client aptos.AptosRpcClient) CCIPOfframp

func DeployToExistingObject

func DeployToExistingObject(
	auth aptos.TransactionSigner,
	client aptos.AptosRpcClient,
	objectAddress, ccipAddress, mcmsAddress aptos.AccountAddress,
) (*api.PendingTransaction, CCIPOfframp, error)

DeployToExistingObject deploys the CCIP offramp package to an existing code object. This should not be used in production, where CCIP is deployed via MCMS and the offramp is deployed to the same object as CCIP.

type CCIPOfframpContract

type CCIPOfframpContract struct {
	// contains filtered or unexported fields
}

func (CCIPOfframpContract) Address

func (CCIPOfframpContract) Offramp

Directories

Path Synopsis

Jump to