mcms

package
v0.0.0-...-67263d3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: MIT Imports: 10 Imported by: 7

Documentation

Index

Constants

const (
	DefaultSeed = "chainlink_mcms"
)

Variables

Functions

func Compile

func Compile(address, owner aptos.AccountAddress) (compile.CompiledPackage, error)

Types

type MCMS

func Bind

func Bind(
	address aptos.AccountAddress,
	client aptos.AptosRpcClient,
) MCMS

func DeployToResourceAccount

func DeployToResourceAccount(
	auth aptos.TransactionSigner,
	client aptos.AptosRpcClient,
	seed ...string,
) (aptos.AccountAddress, *api.PendingTransaction, MCMS, error)

DeployToResourceAccount deploys the MCMS contract to a new resource account. The address of that resource account is determined by the deployer account + an optional seed. If no seed is provided, the default seed DefaultSeed is used. The initial owner will be the address of the deployer account.

type MCMSContract

type MCMSContract struct {
	// contains filtered or unexported fields
}

func (MCMSContract) Address

func (M MCMSContract) Address() aptos.AccountAddress

func (MCMSContract) MCMS

func (MCMSContract) MCMSAccount

func (MCMSContract) MCMSDeployer

func (MCMSContract) MCMSExecutor

func (MCMSContract) MCMSRegistry

Directories

Path Synopsis

Jump to