platform

package
v0.0.0-...-6952c6b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: MIT Imports: 7 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

Functions

func Compile

func Compile(ownerAddress aptos.AccountAddress) (compile.CompiledPackage, error)

Types

type Platform

type Platform interface {
	Address() aptos.AccountAddress

	Forwarder() module_forwarder.ForwarderInterface
	Storage() module_storage.StorageInterface
}

func Bind

func Bind(address aptos.AccountAddress, client aptos.AptosRpcClient) Platform

func DeployToObject

DeployToObject deploys the Platform contract to a new named object. The resulting address will be calculated using the deployer's account address and the next sequence number

type PlatformContract

type PlatformContract struct {
	// contains filtered or unexported fields
}

func (PlatformContract) Address

func (PlatformContract) Forwarder

func (PlatformContract) Storage

Directories

Path Synopsis

Jump to