ccip

package
v0.0.0-...-67263d3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version1_6_0 = *semver.MustParse("1.6.0")

Functions

This section is empty.

Types

type AcceptTokenAdmin

type AcceptTokenAdmin struct{}

func (AcceptTokenAdmin) Apply

func (AcceptTokenAdmin) VerifyPreconditions

func (t AcceptTokenAdmin) VerifyPreconditions(env cldf.Environment, cfg config.AcceptTokenAdminInput) error

type AcceptTokenOwnership

type AcceptTokenOwnership struct{}

func (AcceptTokenOwnership) Apply

func (AcceptTokenOwnership) VerifyPreconditions

type AcceptTokenPoolOwnership

type AcceptTokenPoolOwnership struct{}

func (AcceptTokenPoolOwnership) Apply

func (AcceptTokenPoolOwnership) VerifyPreconditions

type AddTokenPool

type AddTokenPool struct{}

AddTokenPool deploys token pools and sets up tokens on lanes

func (AddTokenPool) Apply

func (AddTokenPool) VerifyPreconditions

func (cs AddTokenPool) VerifyPreconditions(env cldf.Environment, cfg config.AddTokenPoolConfig) error

type DeployAptosChain

type DeployAptosChain struct{}

DeployAptosChain deploys Aptos chain packages and modules

func (DeployAptosChain) Apply

func (DeployAptosChain) VerifyPreconditions

func (cs DeployAptosChain) VerifyPreconditions(env cldf.Environment, config config.DeployAptosChainConfig) error

type DeployCurseMCMS

type DeployCurseMCMS struct{}

DeployCurseMCMS deploys and configures the CurseMCMS contract on Aptos chains.

func (DeployCurseMCMS) Apply

func (DeployCurseMCMS) VerifyPreconditions

func (cs DeployCurseMCMS) VerifyPreconditions(env cldf.Environment, cfg config.DeployCurseMCMSConfig) error

type DeployRegulatedToken

type DeployRegulatedToken struct{}

DeployRegulatedToken deploys and initializes a regulated token directly with the deployer signer (regulated_token cannot be deployed via MCMS due to DFA re-entrancy), transfers ownership and admin role to the MCMS registry owner, and returns a timelock proposal containing accept_ownership and accept_admin.

func (DeployRegulatedToken) Apply

func (DeployRegulatedToken) VerifyPreconditions

type DeployTokenFaucet

type DeployTokenFaucet struct{}

func (DeployTokenFaucet) Apply

func (DeployTokenFaucet) VerifyPreconditions

func (d DeployTokenFaucet) VerifyPreconditions(env cldf.Environment, cfg config.DeployTokenFaucetInput) error

type DynamicCS

type DynamicCS struct{}

DynamicCS enables dynamic execution of multiple Aptos operations at runtime without requiring dedicated changesets. It allows for flexible, configurable operation sequences to be applied based on runtime input, streamlining the process of managing Aptos chain changes.

func (DynamicCS) Apply

func (DynamicCS) VerifyPreconditions

func (cs DynamicCS) VerifyPreconditions(env cldf.Environment, cfg config.DynamicConfig) error

type ExecuteOwnershipTransfer

type ExecuteOwnershipTransfer struct{}

func (ExecuteOwnershipTransfer) VerifyPreconditions

type ExecuteTokenPoolOwnershipTransfer

type ExecuteTokenPoolOwnershipTransfer struct{}

func (ExecuteTokenPoolOwnershipTransfer) VerifyPreconditions

type MigrateOnRampDestChainConfigsToV2

type MigrateOnRampDestChainConfigsToV2 struct{}

func (MigrateOnRampDestChainConfigsToV2) VerifyPreconditions

type MintToken

type MintToken struct{}

func (MintToken) Apply

func (MintToken) VerifyPreconditions

func (m MintToken) VerifyPreconditions(env cldf.Environment, cfg config.MintTokenInput) error

type TransferTokenAdmin

type TransferTokenAdmin struct{}

func (TransferTokenAdmin) Apply

func (TransferTokenAdmin) VerifyPreconditions

func (t TransferTokenAdmin) VerifyPreconditions(env cldf.Environment, cfg config.TransferTokenAdminInput) error

type TransferTokenOwnership

type TransferTokenOwnership struct{}

func (TransferTokenOwnership) Apply

func (TransferTokenOwnership) VerifyPreconditions

type TransferTokenPoolOwnership

type TransferTokenPoolOwnership struct{}

func (TransferTokenPoolOwnership) Apply

func (TransferTokenPoolOwnership) VerifyPreconditions

type UpgradeAptosChain

type UpgradeAptosChain struct{}

UpgradeAptosChain upgrades Aptos chain packages and modules

func (UpgradeAptosChain) Apply

func (UpgradeAptosChain) VerifyPreconditions

func (cs UpgradeAptosChain) VerifyPreconditions(env cldf.Environment, cfg config.UpgradeAptosChainConfig) error

Directories

Path Synopsis
rmn

Jump to