Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var FunctionInfo = bind.MustParseFunctionInfo( module_offramp.FunctionInfo, module_ocr3_base.FunctionInfo, )
Functions ¶
func Compile ¶
func Compile(ccipAddress, mcmsAddress aptos.AccountAddress, registerMCMSEntrypoints bool) (compile.CompiledPackage, error)
Types ¶
type CCIPOfframp ¶
type CCIPOfframp interface {
Address() aptos.AccountAddress
Offramp() module_offramp.OfframpInterface
}
func Bind ¶
func Bind(address aptos.AccountAddress, client aptos.AptosRpcClient) CCIPOfframp
func DeployToExistingObject ¶
func DeployToExistingObject( auth aptos.TransactionSigner, client aptos.AptosRpcClient, objectAddress, ccipAddress, mcmsAddress aptos.AccountAddress, ) (*api.PendingTransaction, CCIPOfframp, error)
DeployToExistingObject deploys the CCIP offramp package to an existing code object. This should not be used in production, where CCIP is deployed via MCMS and the offramp is deployed to the same object as CCIP.
type CCIPOfframpContract ¶
type CCIPOfframpContract struct {
// contains filtered or unexported fields
}
func (CCIPOfframpContract) Address ¶
func (c CCIPOfframpContract) Address() aptos.AccountAddress
func (CCIPOfframpContract) Offramp ¶
func (c CCIPOfframpContract) Offramp() module_offramp.OfframpInterface
Click to show internal directories.
Click to hide internal directories.