Documentation
¶
Index ¶
- Constants
- Variables
- func Compile(address, owner aptos.AccountAddress) (compile.CompiledPackage, error)
- type MCMS
- type MCMSContract
- func (M MCMSContract) Address() aptos.AccountAddress
- func (M MCMSContract) MCMS() module_mcms.MCMSInterface
- func (M MCMSContract) MCMSAccount() module_mcms_account.MCMSAccountInterface
- func (M MCMSContract) MCMSDeployer() module_mcms_deployer.MCMSDeployerInterface
- func (M MCMSContract) MCMSExecutor() module_mcms_executor.MCMSExecutorInterface
- func (M MCMSContract) MCMSRegistry() module_mcms_registry.MCMSRegistryInterface
Constants ¶
const (
DefaultSeed = "chainlink_mcms"
)
Variables ¶
Functions ¶
func Compile ¶
func Compile(address, owner aptos.AccountAddress) (compile.CompiledPackage, error)
Types ¶
type MCMS ¶
type MCMS interface {
Address() aptos.AccountAddress
MCMS() module_mcms.MCMSInterface
MCMSAccount() module_mcms_account.MCMSAccountInterface
MCMSDeployer() module_mcms_deployer.MCMSDeployerInterface
MCMSExecutor() module_mcms_executor.MCMSExecutorInterface
MCMSRegistry() module_mcms_registry.MCMSRegistryInterface
}
func Bind ¶
func Bind( address aptos.AccountAddress, client aptos.AptosRpcClient, ) MCMS
func DeployToResourceAccount ¶
func DeployToResourceAccount( auth aptos.TransactionSigner, client aptos.AptosRpcClient, seed ...string, ) (aptos.AccountAddress, *api.PendingTransaction, MCMS, error)
DeployToResourceAccount deploys the MCMS contract to a new resource account. The address of that resource account is determined by the deployer account + an optional seed. If no seed is provided, the default seed DefaultSeed is used. The initial owner will be the address of the deployer account.
type MCMSContract ¶
type MCMSContract struct {
// contains filtered or unexported fields
}
func (MCMSContract) Address ¶
func (M MCMSContract) Address() aptos.AccountAddress
func (MCMSContract) MCMS ¶
func (M MCMSContract) MCMS() module_mcms.MCMSInterface
func (MCMSContract) MCMSAccount ¶
func (M MCMSContract) MCMSAccount() module_mcms_account.MCMSAccountInterface
func (MCMSContract) MCMSDeployer ¶
func (M MCMSContract) MCMSDeployer() module_mcms_deployer.MCMSDeployerInterface
func (MCMSContract) MCMSExecutor ¶
func (M MCMSContract) MCMSExecutor() module_mcms_executor.MCMSExecutorInterface
func (MCMSContract) MCMSRegistry ¶
func (M MCMSContract) MCMSRegistry() module_mcms_registry.MCMSRegistryInterface
Click to show internal directories.
Click to hide internal directories.