Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var FunctionInfo = bind.MustParseFunctionInfo( module_forwarder.FunctionInfo, module_storage.FunctionInfo, )
Functions ¶
func Compile ¶
func Compile(ownerAddress aptos.AccountAddress) (compile.CompiledPackage, error)
Types ¶
type Platform ¶
type Platform interface {
Address() aptos.AccountAddress
Forwarder() module_forwarder.ForwarderInterface
Storage() module_storage.StorageInterface
}
func Bind ¶
func Bind(address aptos.AccountAddress, client aptos.AptosRpcClient) Platform
func DeployToObject ¶
func DeployToObject( auth aptos.TransactionSigner, client aptos.AptosRpcClient, ownerAddress aptos.AccountAddress, ) (aptos.AccountAddress, *api.PendingTransaction, Platform, error)
DeployToObject deploys the Platform contract to a new named object. The resulting address will be calculated using the deployer's account address and the next sequence number
type PlatformContract ¶
type PlatformContract struct {
// contains filtered or unexported fields
}
func (PlatformContract) Address ¶
func (C PlatformContract) Address() aptos.AccountAddress
func (PlatformContract) Forwarder ¶
func (C PlatformContract) Forwarder() module_forwarder.ForwarderInterface
func (PlatformContract) Storage ¶
func (C PlatformContract) Storage() module_storage.StorageInterface
Click to show internal directories.
Click to hide internal directories.