Documentation
¶
Index ¶
- Variables
- type AcceptTokenAdmin
- type AcceptTokenOwnership
- type AcceptTokenPoolOwnership
- type AddTokenPool
- type DeployAptosChain
- type DeployCurseMCMS
- type DeployRegulatedToken
- type DeployTokenFaucet
- type DynamicCS
- type ExecuteOwnershipTransfer
- type ExecuteTokenPoolOwnershipTransfer
- type MigrateOnRampDestChainConfigsToV2
- type MintToken
- type TransferTokenAdmin
- type TransferTokenOwnership
- type TransferTokenPoolOwnership
- type UpgradeAptosChain
Constants ¶
This section is empty.
Variables ¶
var Version1_6_0 = *semver.MustParse("1.6.0")
Functions ¶
This section is empty.
Types ¶
type AcceptTokenAdmin ¶
type AcceptTokenAdmin struct{}
func (AcceptTokenAdmin) Apply ¶
func (t AcceptTokenAdmin) Apply(env cldf.Environment, cfg config.AcceptTokenAdminInput) (cldf.ChangesetOutput, error)
func (AcceptTokenAdmin) VerifyPreconditions ¶
func (t AcceptTokenAdmin) VerifyPreconditions(env cldf.Environment, cfg config.AcceptTokenAdminInput) error
type AcceptTokenOwnership ¶
type AcceptTokenOwnership struct{}
func (AcceptTokenOwnership) Apply ¶
func (t AcceptTokenOwnership) Apply(env cldf.Environment, cfg config.AcceptTokenOwnershipInput) (cldf.ChangesetOutput, error)
func (AcceptTokenOwnership) VerifyPreconditions ¶
func (t AcceptTokenOwnership) VerifyPreconditions(env cldf.Environment, cfg config.AcceptTokenOwnershipInput) error
type AcceptTokenPoolOwnership ¶
type AcceptTokenPoolOwnership struct{}
func (AcceptTokenPoolOwnership) Apply ¶
func (a AcceptTokenPoolOwnership) Apply(env cldf.Environment, cfg config.AcceptTokenPoolOwnershipInput) (cldf.ChangesetOutput, error)
func (AcceptTokenPoolOwnership) VerifyPreconditions ¶
func (a AcceptTokenPoolOwnership) VerifyPreconditions(env cldf.Environment, cfg config.AcceptTokenPoolOwnershipInput) error
type AddTokenPool ¶
type AddTokenPool struct{}
AddTokenPool deploys token pools and sets up tokens on lanes
func (AddTokenPool) Apply ¶
func (cs AddTokenPool) Apply(env cldf.Environment, cfg config.AddTokenPoolConfig) (cldf.ChangesetOutput, error)
func (AddTokenPool) VerifyPreconditions ¶
func (cs AddTokenPool) VerifyPreconditions(env cldf.Environment, cfg config.AddTokenPoolConfig) error
type DeployAptosChain ¶
type DeployAptosChain struct{}
DeployAptosChain deploys Aptos chain packages and modules
func (DeployAptosChain) Apply ¶
func (cs DeployAptosChain) Apply(env cldf.Environment, cfg config.DeployAptosChainConfig) (cldf.ChangesetOutput, error)
func (DeployAptosChain) VerifyPreconditions ¶
func (cs DeployAptosChain) VerifyPreconditions(env cldf.Environment, config config.DeployAptosChainConfig) error
type DeployCurseMCMS ¶
type DeployCurseMCMS struct{}
DeployCurseMCMS deploys and configures the CurseMCMS contract on Aptos chains.
func (DeployCurseMCMS) Apply ¶
func (cs DeployCurseMCMS) Apply(env cldf.Environment, cfg config.DeployCurseMCMSConfig) (cldf.ChangesetOutput, error)
func (DeployCurseMCMS) VerifyPreconditions ¶
func (cs DeployCurseMCMS) VerifyPreconditions(env cldf.Environment, cfg config.DeployCurseMCMSConfig) error
type DeployRegulatedToken ¶
type DeployRegulatedToken struct{}
DeployRegulatedToken deploys and initializes a regulated token directly with the deployer signer (regulated_token cannot be deployed via MCMS due to DFA re-entrancy), transfers ownership and admin role to the MCMS registry owner, and returns a timelock proposal containing accept_ownership and accept_admin.
func (DeployRegulatedToken) Apply ¶
func (cs DeployRegulatedToken) Apply(env cldf.Environment, cfg config.DeployRegulatedTokenConfig) (cldf.ChangesetOutput, error)
func (DeployRegulatedToken) VerifyPreconditions ¶
func (cs DeployRegulatedToken) VerifyPreconditions(env cldf.Environment, cfg config.DeployRegulatedTokenConfig) error
type DeployTokenFaucet ¶
type DeployTokenFaucet struct{}
func (DeployTokenFaucet) Apply ¶
func (d DeployTokenFaucet) Apply(env cldf.Environment, cfg config.DeployTokenFaucetInput) (cldf.ChangesetOutput, error)
func (DeployTokenFaucet) VerifyPreconditions ¶
func (d DeployTokenFaucet) VerifyPreconditions(env cldf.Environment, cfg config.DeployTokenFaucetInput) error
type DynamicCS ¶
type DynamicCS struct{}
DynamicCS enables dynamic execution of multiple Aptos operations at runtime without requiring dedicated changesets. It allows for flexible, configurable operation sequences to be applied based on runtime input, streamlining the process of managing Aptos chain changes.
func (DynamicCS) Apply ¶
func (cs DynamicCS) Apply(env cldf.Environment, cfg config.DynamicConfig) (cldf.ChangesetOutput, error)
func (DynamicCS) VerifyPreconditions ¶
func (cs DynamicCS) VerifyPreconditions(env cldf.Environment, cfg config.DynamicConfig) error
type ExecuteOwnershipTransfer ¶
type ExecuteOwnershipTransfer struct{}
func (ExecuteOwnershipTransfer) Apply ¶
func (t ExecuteOwnershipTransfer) Apply(env cldf.Environment, cfg config.ExecuteTokenOwnershipTransferInput) (cldf.ChangesetOutput, error)
func (ExecuteOwnershipTransfer) VerifyPreconditions ¶
func (t ExecuteOwnershipTransfer) VerifyPreconditions(env cldf.Environment, cfg config.ExecuteTokenOwnershipTransferInput) error
type ExecuteTokenPoolOwnershipTransfer ¶
type ExecuteTokenPoolOwnershipTransfer struct{}
func (ExecuteTokenPoolOwnershipTransfer) Apply ¶
func (e ExecuteTokenPoolOwnershipTransfer) Apply(env cldf.Environment, cfg config.ExecuteTokenPoolOwnershipTransferInput) (cldf.ChangesetOutput, error)
func (ExecuteTokenPoolOwnershipTransfer) VerifyPreconditions ¶
func (e ExecuteTokenPoolOwnershipTransfer) VerifyPreconditions(env cldf.Environment, cfg config.ExecuteTokenPoolOwnershipTransferInput) error
type MigrateOnRampDestChainConfigsToV2 ¶
type MigrateOnRampDestChainConfigsToV2 struct{}
func (MigrateOnRampDestChainConfigsToV2) Apply ¶
func (cs MigrateOnRampDestChainConfigsToV2) Apply(env cldf.Environment, cfg config.MigrateOnRampDestChainConfigsToV2Config) (cldf.ChangesetOutput, error)
func (MigrateOnRampDestChainConfigsToV2) VerifyPreconditions ¶
func (cs MigrateOnRampDestChainConfigsToV2) VerifyPreconditions(env cldf.Environment, cfg config.MigrateOnRampDestChainConfigsToV2Config) error
type MintToken ¶
type MintToken struct{}
func (MintToken) Apply ¶
func (m MintToken) Apply(env cldf.Environment, cfg config.MintTokenInput) (cldf.ChangesetOutput, error)
func (MintToken) VerifyPreconditions ¶
func (m MintToken) VerifyPreconditions(env cldf.Environment, cfg config.MintTokenInput) error
type TransferTokenAdmin ¶
type TransferTokenAdmin struct{}
func (TransferTokenAdmin) Apply ¶
func (t TransferTokenAdmin) Apply(env cldf.Environment, cfg config.TransferTokenAdminInput) (cldf.ChangesetOutput, error)
func (TransferTokenAdmin) VerifyPreconditions ¶
func (t TransferTokenAdmin) VerifyPreconditions(env cldf.Environment, cfg config.TransferTokenAdminInput) error
type TransferTokenOwnership ¶
type TransferTokenOwnership struct{}
func (TransferTokenOwnership) Apply ¶
func (t TransferTokenOwnership) Apply(env cldf.Environment, cfg config.TransferTokenOwnershipInput) (cldf.ChangesetOutput, error)
func (TransferTokenOwnership) VerifyPreconditions ¶
func (t TransferTokenOwnership) VerifyPreconditions(env cldf.Environment, cfg config.TransferTokenOwnershipInput) error
type TransferTokenPoolOwnership ¶
type TransferTokenPoolOwnership struct{}
func (TransferTokenPoolOwnership) Apply ¶
func (t TransferTokenPoolOwnership) Apply(env cldf.Environment, cfg config.TransferTokenPoolOwnershipInput) (cldf.ChangesetOutput, error)
func (TransferTokenPoolOwnership) VerifyPreconditions ¶
func (t TransferTokenPoolOwnership) VerifyPreconditions(env cldf.Environment, cfg config.TransferTokenPoolOwnershipInput) error
type UpgradeAptosChain ¶
type UpgradeAptosChain struct{}
UpgradeAptosChain upgrades Aptos chain packages and modules
func (UpgradeAptosChain) Apply ¶
func (cs UpgradeAptosChain) Apply(env cldf.Environment, cfg config.UpgradeAptosChainConfig) (cldf.ChangesetOutput, error)
func (UpgradeAptosChain) VerifyPreconditions ¶
func (cs UpgradeAptosChain) VerifyPreconditions(env cldf.Environment, cfg config.UpgradeAptosChainConfig) error